aboutsummaryrefslogtreecommitdiffstats
path: root/src/libstat
diff options
context:
space:
mode:
authorVsevolod Stakhov <vsevolod@rspamd.com>2023-12-11 14:38:20 +0000
committerVsevolod Stakhov <vsevolod@rspamd.com>2023-12-11 14:38:20 +0000
commit6b39c0f971fa101cf56250792b4892a0c665ba2b (patch)
tree4d214bfb29b48224273c6b8e537799ba22094283 /src/libstat
parent202c586ce763a3696b6526c0ddfce3dee76ea879 (diff)
downloadrspamd-6b39c0f971fa101cf56250792b4892a0c665ba2b.tar.gz
rspamd-6b39c0f971fa101cf56250792b4892a0c665ba2b.zip
[Minor] Link runtime to the proper statfile context
Diffstat (limited to 'src/libstat')
-rw-r--r--src/libstat/backends/redis_backend.cxx8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/libstat/backends/redis_backend.cxx b/src/libstat/backends/redis_backend.cxx
index 30dd13107..5e222c6cb 100644
--- a/src/libstat/backends/redis_backend.cxx
+++ b/src/libstat/backends/redis_backend.cxx
@@ -603,9 +603,11 @@ rspamd_redis_runtime(struct rspamd_task *task,
object_expanded, stcf->is_spam);
if (maybe_existing) {
- /* Update stcf to correspond to what we have been asked */
- maybe_existing.value()->stcf = stcf;
- return maybe_existing.value();
+ auto *rt = maybe_existing.value();
+ /* Update stcf and ctx to correspond to what we have been asked */
+ rt->stcf = stcf;
+ rt->ctx = ctx;
+ return rt;
}
}